#! /usr/bin/python
# -*- coding: utf-8 -*-

import os
import re
import argparse


class ServiceGenerator(object):
    def __init__(self):
        self.parser = argparse.ArgumentParser(
            'sg',
            description='''CIS service.yaml config generator
                           by anton.andersson@visma.com''')
        self.args = self._setup_args()
        self.parms = self._get_parms()
        self.cparms = self._get_config_parms()
        self.branch = self._get_branch()

    def _setup_args(self):
        self.parser.add_argument(
            "file", type=str, help="input file")
        self.parser.add_argument(
            "-r", "--remote", help="set to remote",
            action='store_true')
        self.parser.add_argument(
            "-i", "--internal", help="set to internal",
            action='store_true')
        return self.parser.parse_args()

    def _dump(self):
        name, ext = os.path.splitext(
            self.args.file)
        s = ' '
        with open('service.yaml', 'w') as of:
            of.write('%s\n' % self.branch)
            of.write('%sintegrations:\n' % (s * 4))
            of.write('%s%s:\n' % (s * 8, name))
            of.write('%sdisabled: *%s_disabled' % (s * 12, name))
            of.write('\n' * 2)
            of.write('%scomponents:\n' % (s * 12))
            of.write('%s- %s%s\n' % (s * 14, name, ext))
            of.write('\n')
            of.write('%sparameters:\n' % (s * 12))
            if self.parms and not self.cparms:
                for parm in self.parms:
                    of.write('%s%s: *%s\n' % (s * 16, parm, parm))
                of.write('\n')
            else:
                of.write('\n')
            of.write('%sidentifiers: *%s_identifier\n' % (s * 12, name))
            if self.cparms:
                of.write('\n')
                of.write('%striggers:\n' % (s * 4))
                of.write('%s%s:\n' % (s * 8, name))
                of.write('%sdisabled: *%s_disabled\n' % (
                    s * 12, name))
                of.write('\n')
                of.write('%scomponents:\n' % (s * 12))
                of.write('%s- %s%s\n' % (s * 14, name, ext))
                of.write('\n')
                of.write('%sparameters:\n' % (s * 12))
                for parm in self.parms:
                    of.write('%s%s: *%s\n' % (s * 16, parm, parm))
                of.write('\n')
                of.write('%sconfigurations:\n' % (s * 12))
                of.write('%sitems: *%s_config_item\n' % (s * 16, name))
                for parm in self.cparms:
                    of.write('%s# %s\n' % (s * 23, parm))
                of.write('\n')
                of.write('%sscheduler:\n' % (s * 12))
                of.write('%sitems: *%s_scheduler_item\n' % (s * 16, name))

    def _get_parms(self):
        with open(self.args.file, 'r') as f:
            lines = f.readlines()
            parms = [re.findall(r"['\"](.*?)['\"]|$", line)[0]
                     for line in lines if 'get_parameter' in line or
                     'require_param' in line or 'get_param' in line]
            parms = [parm.replace('+', '')
                     .replace('-', '')
                     .replace('?', '') for parm in parms]
            parms = filter(None, parms)
            return parms

    def _get_config_parms(self):
        with open(self.args.file, 'r') as f:
            lines = f.readlines()
            parms = [re.findall(r"['\"](.*?)['\"]|$", line)[0]
                     for line in lines if 'get_config_parameter' in line]
            parms = [parm.replace('+', '')
                     .replace('-', '')
                     .replace('?', '') for parm in parms]
            return parms

    def _get_branch(self):
        if self.args.internal:
            return 'internal:'
        else:
            return 'remote:'

sg = ServiceGenerator()
sg._dump()

